
# build
python -m build 

# publish
python -m twine upload dist/* --verbose

pypi-AgEIcHlwaS5vcmcCJDdlNGExNjQ0LWVmMjItNGVmYi1iNTk5LTA2Y2M5NmNhZTcyZgACKlszLCIyNDJmOGVkZi00NjZhLTRiZWQtYTRiYi0wYzdlODEyMTk1NWUiXQAABiAYGNSxQdmhhbdXZQ7tRKqzN6FdmsovLR4x0F6ZiQF-pw